@@ -78,6 +78,7 @@ func TestTranspilerVariants(t *testing.T) {
 	}{
 		{"Output style compressed", Options{}, Args{Source: "div { color: #ccc; }", OutputStyle: OutputStyleCompressed}, Result{CSS: "div{color:#ccc}"}},
 		{"Enable Source Map", Options{}, Args{Source: "div{color:blue;}", URL: "file://myproject/main.scss", OutputStyle: OutputStyleCompressed, EnableSourceMap: true}, Result{CSS: "div{color:blue}", SourceMap: "{\"version\":3,\"sourceRoot\":\"\",\"sources\":[\"file://myproject/main.scss\"],\"names\":[],\"mappings\":\"AAAA\"}"}},
+		{"Enable Source Map with sources", Options{}, Args{Source: "div{color:blue;}", URL: "file://myproject/main.scss", OutputStyle: OutputStyleCompressed, EnableSourceMap: true, SourceMapIncludeSources: true}, Result{CSS: "div{color:blue}", SourceMap: "{\"version\":3,\"sourceRoot\":\"\",\"sources\":[\"file://myproject/main.scss\"],\"names\":[],\"mappings\":\"AAAA\",\"sourcesContent\":[\"div{color:blue;}\"]}"}},
 		{"Sass syntax", Options{}, Args{
 			Source: `$font-stack:    Helvetica, sans-serif
 $primary-color: #333
@@ -89,7 +90,7 @@ body
 			OutputStyle:  OutputStyleCompressed,
 			SourceSyntax: SourceSyntaxSASS,
 		}, Result{CSS: "body{font:100% Helvetica,sans-serif;color:#333}"}},
-		{"Import resolver with source map", Options{}, Args{Source: "@import \"colors\";\ndiv { p { color: $white; } }", EnableSourceMap: true, ImportResolver: colorsResolver}, Result{CSS: "div p {\n  color: #ffff;\n}", SourceMap: "{\"version\":3,\"sourceRoot\":\"\",\"sources\":[\"data:;charset=utf-8,@import%20%22colors%22;%0Adiv%20%7B%20p%20%7B%20color:%20$white;%20%7D%20%7D\",\"file:///mycolors/scss/colors_myfile.scss\"],\"names\":[],\"mappings\":\"AACM;EAAI,OCDC\"}"}},
+		{"Import resolver with source map", Options{}, Args{Source: "@import \"colors\";\ndiv { p { color: $white; } }", EnableSourceMap: true, ImportResolver: colorsResolver}, Result{CSS: "div p {\n  color: white;\n}", SourceMap: "{\"version\":3,\"sourceRoot\":\"\",\"sources\":[\"data:;charset=utf-8,@import%20%22colors%22;%0Adiv%20%7B%20p%20%7B%20color:%20$white;%20%7D%20%7D\",\"file:///mycolors/scss/colors_myfile.scss\"],\"names\":[],\"mappings\":\"AACM;EAAI,OCDC\"}"}},
 
 		// Error cases
 		{"Invalid syntax", Options{}, Args{Source: "div { color: $white; }"}, false},
@@ -117,7 +118,7 @@ body
 			} else {
 				expectedResult := test.expect.(Result)
 				c.Assert(err, qt.IsNil)
-				//printJSON(result.SourceMap)
+				// printJSON(result.SourceMap)
 				c.Assert(result, qt.Equals, expectedResult)
 
 			}
@@ -175,11 +176,11 @@ func TestIncludePaths(t *testing.T) {
 
 	ioutil.WriteFile(colors, []byte(`
 $moo:       #f442d1 !default;
-`), 0644)
+`), 0o644)
 
 	ioutil.WriteFile(content, []byte(`
 content { color: #ccc; }
-`), 0644)
+`), 0o644)
 
 	c := qt.New(t)
 	src := `
@@ -199,7 +200,6 @@ div { p { color: $moo; } }`
 	)
 	c.Assert(err, qt.IsNil)
 	c.Assert(result.CSS, qt.Equals, "content{color:#ccc}div p{color:#f442d1}")
-
 }
 
 func TestTranspilerParallel(t *testing.T) {
@@ -234,12 +234,10 @@ func TestTranspilerParallelImportResolver(t *testing.T) {
 	c := qt.New(t)
 
 	createImportResolver := func(width int) ImportResolver {
-
 		return testImportResolver{
 			name:    "widths",
 			content: fmt.Sprintf(`$width:  %d`, width),
 		}
-
 	}
 
 	transpiler, clean := newTestTranspiler(c, Options{})
@@ -253,7 +251,6 @@ func TestTranspilerParallelImportResolver(t *testing.T) {
 			defer wg.Done()
 
 			for j := 0; j < 10; j++ {
-
 				for k := 0; k < 20; k++ {
 					args := Args{
 						OutputStyle:    OutputStyleCompressed,
@@ -276,7 +273,6 @@ div { p { width: $width; } }`,
 	}
 
 	wg.Wait()
-
 }
 
 func TestTranspilerClose(t *testing.T) {
@@ -408,6 +404,15 @@ func TestHasScheme(t *testing.T) {
 	c.Assert(hasScheme("http://foo"), qt.Equals, true)
 	c.Assert(hasScheme("123:foo"), qt.Equals, false)
 	c.Assert(hasScheme("foo"), qt.Equals, false)
+}
+
+func TestVersion(t *testing.T) {
+	c := qt.New(t)
+
+	version, err := Version(getSassEmbeddedFilename())
+	c.Assert(err, qt.IsNil)
+	c.Assert(version, qt.Not(qt.Equals), "")
+	c.Assert(version.ProtocolVersion, qt.Equals, "1.1.0")
 
 }
 
@@ -437,5 +442,4 @@ func printJSON(s string) {
 	json.Unmarshal([]byte(s), &m)
 	b, _ := json.MarshalIndent(m, "", "  ")
 	fmt.Printf("%s", b)
-
 }
